aboutsummaryrefslogtreecommitdiffstats
path: root/calendar/cal-client/cal-listener.h
diff options
context:
space:
mode:
authorFederico Mena Quintero <federico@helixcode.com>2000-01-29 18:48:09 +0800
committerArturo Espinosa <unammx@src.gnome.org>2000-01-29 18:48:09 +0800
commit390f24328e589387b7a2b26a36c5f138cc636c1b (patch)
tree5a2fcb9dced60d4e4fd670e8077e4aa6058cb5b0 /calendar/cal-client/cal-listener.h
parent542fbe8d77f0505bf4e8ef4b03e8e2a1762309e6 (diff)
downloadgsoc2013-evolution-390f24328e589387b7a2b26a36c5f138cc636c1b.tar
gsoc2013-evolution-390f24328e589387b7a2b26a36c5f138cc636c1b.tar.gz
gsoc2013-evolution-390f24328e589387b7a2b26a36c5f138cc636c1b.tar.bz2
gsoc2013-evolution-390f24328e589387b7a2b26a36c5f138cc636c1b.tar.lz
gsoc2013-evolution-390f24328e589387b7a2b26a36c5f138cc636c1b.tar.xz
gsoc2013-evolution-390f24328e589387b7a2b26a36c5f138cc636c1b.tar.zst
gsoc2013-evolution-390f24328e589387b7a2b26a36c5f138cc636c1b.zip
Changed the namespace from GNOME::Calendar to Evolution::Calendar.
2000-01-30 Federico Mena Quintero <federico@helixcode.com> * evolution-calendar.idl: Changed the namespace from GNOME::Calendar to Evolution::Calendar. (Listener::LoadStatus): Fixed SUCESSS -> SUCCESS typo. And I never noticed it in the implementation. Ain't M-/ grand? * Makefile.am: Changed ocurrences of gnome-calendar.idl to evolution-calendar.idl. * *.[ch]: Changed GNOME_Calendar_foo identifiers to Evolution_Calendar_foo. svn path=/trunk/; revision=1652
Diffstat (limited to 'calendar/cal-client/cal-listener.h')
-rw-r--r--calendar/cal-client/cal-listener.h22
1 files changed, 12 insertions, 10 deletions
diff --git a/calendar/cal-client/cal-listener.h b/calendar/cal-client/cal-listener.h
index 22853212ee..e339e3e3ed 100644
--- a/calendar/cal-client/cal-listener.h
+++ b/calendar/cal-client/cal-listener.h
@@ -1,4 +1,4 @@
/* GNOME calendar listener
*
* Copyright (C) 2000 Helix Code, Inc.
*
@@ -24,7 +24,7 @@
#include <libgnome/gnome-defs.h>
#include <bonobo/bonobo-object.h>
-#include "gnome-calendar.h"
+#include "evolution-calendar.h"
BEGIN_GNOME_DECLS
@@ -58,22 +58,24 @@ struct _CalListenerClass {
void (* cal_loaded) (CalListener *listener,
CalListenerLoadStatus status,
- GNOME_Calendar_Cal cal);
- void (* obj_added) (CalListener *listener, GNOME_Calendar_CalObj calobj);
- void (* obj_removed) (CalListener *listener, GNOME_Calendar_CalObjUID uid);
- void (* obj_changed) (CalListener *listener, GNOME_Calendar_CalObj calobj);
+ Evolution_Calendar_Cal cal);
+ void (* obj_added) (CalListener *listener, Evolution_Calendar_CalObj calobj);
+ void (* obj_removed) (CalListener *listener, Evolution_Calendar_CalObjUID uid);
+ void (* obj_changed) (CalListener *listener, Evolution_Calendar_CalObj calobj);
};
GtkType cal_listener_get_type (void);
-CalListener *cal_listener_construct (CalListener *listener, GNOME_Calendar_Listener corba_listener);
-GNOME_Calendar_Listener cal_listener_corba_object_create (BonoboObject *object);
+CalListener *cal_listener_construct (CalListener *listener,
+ Evolution_Calendar_Listener corba_listener);
+
+Evolution_Calendar_Listener cal_listener_corba_object_create (BonoboObject *object);
CalListener *cal_listener_new (void);
-GNOME_Calendar_Cal cal_listener_get_calendar (CalListener *listener);
+Evolution_Calendar_Cal cal_listener_get_calendar (CalListener *listener);
-POA_GNOME_Calendar_Listener__epv *cal_listener_get_epv (void);
+POA_Evolution_Calendar_Listener__epv *cal_listener_get_epv (void);
@@ -1,4 +1,4 @@
-/* GNOME calendar listener
+/* Evolution calendar listener
*
* Copyright (C) 2000 Helix Code, Inc.